//+------------------------------------------------------------------+
//|                                               ControlsDialog.mqh |
//|                        Copyright 2011, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#include <Controls\Dialog.mqh>
#include <Controls\Button.mqh>
#include <Controls\Edit.mqh>
#include <Controls\Label.mqh>
#include <Controls\ListView.mqh>
#include <Controls\ComboBox.mqh>
#include <Controls\SpinEdit.mqh>
#include <Controls\RadioGroup.mqh>
#include <Controls\CheckGroup.mqh>

//+------------------------------------------------------------------+
//| defines                                                          |
//+------------------------------------------------------------------+
//--- indents and gaps
#define INDENT_LEFT                         (11)      // indent from left (with allowance for border width)
#define INDENT_TOP                          (11)      // indent from top (with allowance for border width)
#define INDENT_RIGHT                        (11)      // indent from right (with allowance for border width)
#define INDENT_BOTTOM                       (11)      // indent from bottom (with allowance for border width)
#define CONTROLS_GAP_X                      (5)       // gap by X coordinate
#define CONTROLS_GAP_Y                      (5)       // gap by Y coordinate
//--- for buttons
#define BUTTON_WIDTH                        (100)     // size by X coordinate
#define BUTTON_HEIGHT                       (20)      // size by Y coordinate
//--- for the indication area
#define EDIT_HEIGHT                         (20)      // size by Y coordinate
//--- for group controls
#define GROUP_WIDTH                         (100)     // size by X coordinate
#define LIST_HEIGHT                         (204)     // size by Y coordinate
#define RADIO_HEIGHT                        (46)      // size by Y coordinate
#define CHECK_HEIGHT                        (185)      // size by Y coordinate
#define HEIGHT_LAB_PLANET                   (18)      // size by Y coordinate per labels dei pianeti
//+------------------------------------------------------------------+
//| Class CControlsDialog                                            |
//| Usage: main dialog of the Controls application                   |
//+------------------------------------------------------------------+
class CControlsDialog : public CAppDialog
  {
private:
   CButton           m_button2;                       // the button object
   CButton           m_button3;                       // the fixed button object
   CListView         m_list_view;                     // the list object
   CComboBox         m_combo_box;                     // the dropdown list object

public:
     CLabel            m_label_aspect;                     // label
  CEdit             m_edit;                          // the display field object
  CSpinEdit         m_spin_edit;                     // the up-down object
    CEdit             m_edit_pa;                          // the display field object
  CCheckGroup          m_check_box_aspect;
   CButton           m_buttonredraw;                       // the button object
   CRadioGroup       m_radio_group;                   // the radio buttons group object
   CCheckGroup       m_check_group;                   // the check box group object
   CLabel            m_label_box;                     // label
    CLabel            m_label_pa;                   
  CLabel            m_label_Mercury;                   
    CLabel            m_label_Venus;                   
   CLabel            m_label_EarthSun;                   
   CLabel            m_label_Mars;                   
   CLabel            m_label_Jupiter;                   
   CLabel            m_label_Saturn;                   
   CLabel            m_label_Uranus;                   
   CLabel            m_label_Neptune;                   
   CLabel            m_label_Pluto;                   
   CLabel            m_label_Moon;                   
                    CControlsDialog(void);
                    ~CControlsDialog(void);
   //--- create
   virtual bool      Create(const long chart,const string name,const int subwin,const int x1,const int y1,const int x2,const int y2);
   //--- chart event handler
   virtual bool      OnEvent(const int id,const long& lparam,const double& dparam,const string& sparam);

protected:
   //--- create dependent controls
   bool              CreateCheckBox_Aspect(void);
   bool              CreateEdit(void);
   bool              CreateEditPA(void);
   bool              CreateButtonRedraw(void);
   bool              CreateButton2(void);
   bool              CreateButton3(void);
   bool              CreateSpinEdit(void);
   bool              CreateListView(void);
   bool              CreateComboBox(void);
   bool              CreateRadioGroup(void);
   bool              CreateCheckGroup(void);
   bool              CreateLabelBox(void);
   bool              CreateLabelAspect(void);
   bool              CreateLabelPA(void);
   bool              CreateLabelMercury(void);
   bool              CreateLabelVenus(void);
   bool              CreateLabelEarthSun(void);
   bool              CreateLabelMars(void);
   bool              CreateLabelJupiter(void);
   bool              CreateLabelSaturn(void);
   bool              CreateLabelUranus(void);
   bool              CreateLabelNeptune(void);
   bool              CreateLabelPluto(void);
   bool              CreateLabelMoon(void);
 //--- handlers of the dependent controls events
   void              OnClickButtonRedraw(void);
   void              OnClickButton2(void);
   void              OnClickButton3(void);
   void              OnChangeSpinEdit(void);
   void              OnChangeListView(void);
   void              OnChangeComboBox(void);
   void              OnChangeRadioGroup(void);
   void              OnChangeCheckGroup(void);
   void              OnEditPA(void);
  };
//+------------------------------------------------------------------+
//| Event Handling                                                   |
//+------------------------------------------------------------------+
EVENT_MAP_BEGIN(CControlsDialog)
   ON_EVENT(ON_CLICK,m_buttonredraw,OnClickButtonRedraw)
   ON_EVENT(ON_CLICK,m_button2,OnClickButton2)
   ON_EVENT(ON_CLICK,m_button3,OnClickButton3)
   ON_EVENT(ON_CHANGE,m_spin_edit,OnChangeSpinEdit)
   ON_EVENT(ON_CHANGE,m_list_view,OnChangeListView)
   ON_EVENT(ON_CHANGE,m_combo_box,OnChangeComboBox)
   ON_EVENT(ON_CHANGE,m_radio_group,OnChangeRadioGroup)
   ON_EVENT(ON_CHANGE,m_check_group,OnChangeCheckGroup)
   ON_EVENT (CHARTEVENT_OBJECT_ENDEDIT,m_edit_pa,OnEditPA)
EVENT_MAP_END(CAppDialog)
//+------------------------------------------------------------------+
//| Constructor                                                      |
//+------------------------------------------------------------------+
CControlsDialog::CControlsDialog(void)
  {
  }
//+------------------------------------------------------------------+
//| Destructor                                                       |
//+------------------------------------------------------------------+
CControlsDialog::~CControlsDialog(void)
  {
  }
//+------------------------------------------------------------------+
//| Create                                                           |
//+------------------------------------------------------------------+
bool CControlsDialog::Create(const long chart,const string name,const int subwin,const int x1,const int y1,const int x2,const int y2)
  {
   if(!CAppDialog::Create(chart,name,subwin,x1,y1,x2,y2))                          return(false);
//--- create dependent controls
   if(!CreateEdit())                                                               return(false);
   if(!CreateEditPA())                                                               return(false);
   if(!CreateButtonRedraw())                                                            return(false);
  // if(!CreateButton2())                                                            return(false);
  // if(!CreateButton3())                                                            return(false);
   if(!CreateSpinEdit())                                                           return(false);
   //if(!CreateListView())                                                           return(false);
   if(!CreateRadioGroup())                                                         return(false);
   if(!CreateCheckGroup())                                                         return(false);
   if(!CreateLabelBox())                                                           return(false);
   if(!CreateLabelAspect())                                                           return(false);
   if(!CreateLabelPA())                                                           return(false);
   if(!CreateLabelMercury())                                                           return(false);
   if(!CreateLabelVenus())                                                           return(false);
   if(!CreateLabelEarthSun())                                                           return(false);
   if(!CreateLabelMars())                                                           return(false);
   if(!CreateLabelJupiter())                                                           return(false);
   if(!CreateLabelSaturn())                                                           return(false);
   if(!CreateLabelUranus())                                                           return(false);
   if(!CreateLabelNeptune())                                                           return(false);
   if(!CreateLabelPluto())                                                           return(false);
   if(!CreateLabelMoon())                                                           return(false);
//--- succeed
   return(true);
  }
  //
 
//+------------------------------------------------------------------+
//| Create the display field                                         |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateEdit(void)
  {
//--- coordinates
   int x1=INDENT_LEFT;
   int y1=INDENT_TOP;
   int x2=210;
   int y2=y1+EDIT_HEIGHT;
//--- create
   if(!m_edit.Create(m_chart_id,m_name+"Edit",m_subwin,x1,y1,x2,y2))               return(false);
   if(!m_edit.ReadOnly(true))                                                      return(false);
   if(!Add(m_edit))                                                                return(false);
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
//| Create the "ButtonRedraw" button                                      |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateButtonRedraw(void)
  {
//--- coordinates
   int x1=INDENT_LEFT;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y);
   int x2=x1+BUTTON_WIDTH;
   int y2=y1+BUTTON_HEIGHT;
//--- create
   if(!m_buttonredraw.Create(m_chart_id,m_name+"ButtonRedraw",m_subwin,x1,y1,x2,y2))         return(false);
   if(!m_buttonredraw.Text("Redraw"))                                                  return(false);
   if(!Add(m_buttonredraw))                                                             return(false);
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
//| Create the "Button2" button                                      |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateButton2(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+(BUTTON_WIDTH+CONTROLS_GAP_X);
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y);
   int x2=x1+BUTTON_WIDTH;
   int y2=y1+BUTTON_HEIGHT;
//--- create
   if(!m_button2.Create(m_chart_id,m_name+"Button2",m_subwin,x1,y1,x2,y2))         return(false);
   if(!m_button2.Text("Button2"))                                                  return(false);
   if(!Add(m_button2))                                                             return(false);
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
//| Create the "Button3" fixed button                                |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateButton3(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+2*(BUTTON_WIDTH+CONTROLS_GAP_X);
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y);
   int x2=x1+BUTTON_WIDTH;
   int y2=y1+BUTTON_HEIGHT;
//--- create
   if(!m_button3.Create(m_chart_id,m_name+"Button3",m_subwin,x1,y1,x2,y2))         return(false);
   if(!m_button3.Text("Locked"))                                                   return(false);
   if(!Add(m_button3))                                                             return(false);
   m_button3.Locking(true);
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
//| Create the "SpinEdit" element                                    |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateSpinEdit(void)
  {
//--- coordinates
   //int x1=INDENT_LEFT;
   //int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+(BUTTON_HEIGHT+CONTROLS_GAP_Y);
   //int x2=x1+GROUP_WIDTH;
   //int y2=y1+EDIT_HEIGHT;
   
   int x1=INDENT_LEFT;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y)+INDENT_TOP+CHECK_HEIGHT;
   int x2=x1+100;
   int y2=y1+20;
//--- create
   if(!m_spin_edit.Create(m_chart_id,m_name+"SpinEdit",m_subwin,x1,y1,x2,y2))       return(false);
   if(!Add(m_spin_edit))                                                            return(false);
   m_spin_edit.MinValue(0);
   m_spin_edit.MaxValue(36);
   //m_spin_edit.Value(4);
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
//| Create the "ListView" element                                    |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateListView(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+GROUP_WIDTH+2*CONTROLS_GAP_X;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+(BUTTON_HEIGHT+CONTROLS_GAP_Y);
   int x2=x1+GROUP_WIDTH;
   int y2=y1+LIST_HEIGHT;
//--- create
   if(!m_list_view.Create(m_chart_id,m_name+"ListView",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_list_view))                                                           return(false);
//--- fill out with strings
   for(int i=0;i<16;i++)
      if(!m_list_view.AddItem("Item "+IntegerToString(i)))                         return(false);
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
//| Create the "ComboBox" element                                    |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateComboBox(void)
  {
//--- coordinates
   int x1=INDENT_LEFT;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y);
   int x2=x1+GROUP_WIDTH;
   int y2=y1+EDIT_HEIGHT;
//--- create
   if(!m_combo_box.Create(m_chart_id,m_name+"ComboBox",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_combo_box))                                                           return(false);
//--- fill out with strings
   for(int i=0;i<16;i++)
      if(!m_combo_box.ItemAdd("Item "+IntegerToString(i)))                         return(false);
//--- succeed
   return(true);
  }

//+------------------------------------------------------------------+
//| Create the "Label" element                                    |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateLabelBox(void)
  {
//--- coordinates
   int x1=INDENT_LEFT;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y);
   int x2=x1+GROUP_WIDTH;
   int y2=y1+EDIT_HEIGHT;
//--- create
   if(!m_label_box.Create(m_chart_id,m_name+"Label",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_box))                                                           return(false);

   if(!m_label_box.Text(""))                         return(false);
//--- succeed
   return(true);
  }
bool CControlsDialog::CreateLabelPA(void)
  {
//--- coordinates
   int x1=INDENT_LEFT;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+25;
   int x2=x1+BUTTON_WIDTH;
   int y2=y1+BUTTON_HEIGHT;

   if(!m_label_pa.Create(m_chart_id,m_name+"LabelPA",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_pa))                                                           return(false);

   if(!m_label_pa.Text("Planet Angle:"))                         return(false);
//--- succeed
   return(true);
  }    
bool CControlsDialog::CreateLabelAspect(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+100;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y)+INDENT_TOP+CHECK_HEIGHT;
   int x2=x1+100;
   int y2=y1+20;

   if(!m_label_aspect.Create(m_chart_id,m_name+"Labelaspect",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_aspect))                                                           return(false);

   if(!m_label_aspect.Text(" Aspects"))                         return(false);
//--- succeed
   return(true);
  }      
//+------------------------------------------------------------------+
//| Create the display field                                         |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateEditPA(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+BUTTON_WIDTH;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+BUTTON_HEIGHT;
   int x2=x1+BUTTON_WIDTH;
   int y2=y1+BUTTON_HEIGHT;
//--- create
   if(!m_edit_pa.Create(m_chart_id,m_name+"EditPA",m_subwin,x1,y1,x2,y2))               return(false);
   if(!Add(m_edit_pa))                                                                return(false);
//--- succeed
   return(true);
  }  
//+------------------------------------------------------------------+
//| Create the "Label" Mercury                                  |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateLabelMercury(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+GROUP_WIDTH+CONTROLS_GAP_X;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y);
   int x2=x1+GROUP_WIDTH;
   int y2=y1+CHECK_HEIGHT;//--- create
   if(!m_label_Mercury.Create(m_chart_id,m_name+"LabelMercury",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_Mercury))                                                           return(false);

   if(!m_label_Mercury.Text(""))                         return(false);
//--- succeed
   return(true);
  }  
//+------------------------------------------------------------------+
//| Create the "Label" Venus                                  |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateLabelVenus(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+GROUP_WIDTH+CONTROLS_GAP_X;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y)+HEIGHT_LAB_PLANET;
   int x2=x1+GROUP_WIDTH;
   int y2=y1+CHECK_HEIGHT;//--- create
   if(!m_label_Venus.Create(m_chart_id,m_name+"LabelVenus",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_Venus))                                                           return(false);

   if(!m_label_Venus.Text(""))                         return(false);
//--- succeed
   return(true);
  }
bool CControlsDialog::CreateLabelEarthSun(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+GROUP_WIDTH+CONTROLS_GAP_X;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y)+2*HEIGHT_LAB_PLANET;
   int x2=x1+GROUP_WIDTH;
   int y2=y1+CHECK_HEIGHT;//--- create
   if(!m_label_EarthSun.Create(m_chart_id,m_name+"LabelEarthSun",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_EarthSun))                                                           return(false);

   if(!m_label_EarthSun.Text(""))                         return(false);
//--- succeed
   return(true);
  }  
bool CControlsDialog::CreateLabelMars(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+GROUP_WIDTH+CONTROLS_GAP_X;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y)+3*HEIGHT_LAB_PLANET;
   int x2=x1+GROUP_WIDTH;
   int y2=y1+CHECK_HEIGHT;//--- create
   if(!m_label_Mars.Create(m_chart_id,m_name+"LabelMars",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_Mars))                                                           return(false);

   if(!m_label_Mars.Text(""))                         return(false);
//--- succeed
   return(true);
  }    
bool CControlsDialog::CreateLabelJupiter(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+GROUP_WIDTH+CONTROLS_GAP_X;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y)+4*HEIGHT_LAB_PLANET;
   int x2=x1+GROUP_WIDTH;
   int y2=y1+CHECK_HEIGHT;//--- create
   if(!m_label_Jupiter.Create(m_chart_id,m_name+"LabelJupiter",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_Jupiter))                                                           return(false);

   if(!m_label_Jupiter.Text(""))                         return(false);
//--- succeed
   return(true);
  }      
 bool CControlsDialog::CreateLabelSaturn(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+GROUP_WIDTH+CONTROLS_GAP_X;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y)+5*HEIGHT_LAB_PLANET;
   int x2=x1+GROUP_WIDTH;
   int y2=y1+CHECK_HEIGHT;//--- create
   if(!m_label_Saturn.Create(m_chart_id,m_name+"LabelSaturn",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_Saturn))                                                           return(false);

   if(!m_label_Saturn.Text(""))                         return(false);
//--- succeed
   return(true);
  }       
 bool CControlsDialog::CreateLabelUranus(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+GROUP_WIDTH+CONTROLS_GAP_X;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y)+6*HEIGHT_LAB_PLANET;
   int x2=x1+GROUP_WIDTH;
   int y2=y1+CHECK_HEIGHT;//--- create
   if(!m_label_Uranus.Create(m_chart_id,m_name+"LabelUranus",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_Uranus))                                                           return(false);

   if(!m_label_Uranus.Text(""))                         return(false);
//--- succeed
   return(true);
  }  
 bool CControlsDialog::CreateLabelNeptune(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+GROUP_WIDTH+CONTROLS_GAP_X;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y)+7*HEIGHT_LAB_PLANET;
   int x2=x1+GROUP_WIDTH;
   int y2=y1+CHECK_HEIGHT;//--- create
   if(!m_label_Neptune.Create(m_chart_id,m_name+"LabelNeptune",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_Neptune))                                                           return(false);

   if(!m_label_Neptune.Text(""))                         return(false);
//--- succeed
   return(true);
  }         
bool CControlsDialog::CreateLabelPluto(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+GROUP_WIDTH+CONTROLS_GAP_X;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y)+8*HEIGHT_LAB_PLANET;
   int x2=x1+GROUP_WIDTH;
   int y2=y1+CHECK_HEIGHT;//--- create
   if(!m_label_Pluto.Create(m_chart_id,m_name+"LabelPluto",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_Pluto))                                                           return(false);

   if(!m_label_Pluto.Text(""))                         return(false);
//--- succeed
   return(true);
  }       
bool CControlsDialog::CreateLabelMoon(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+GROUP_WIDTH+CONTROLS_GAP_X;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y)+9*HEIGHT_LAB_PLANET;
   int x2=x1+GROUP_WIDTH;
   int y2=y1+CHECK_HEIGHT;//--- create
   if(!m_label_Moon.Create(m_chart_id,m_name+"LabelMoon",m_subwin,x1,y1,x2,y2))      return(false);
   if(!Add(m_label_Moon))                                                           return(false);

   if(!m_label_Moon.Text(""))                         return(false);
//--- succeed
   return(true);
  }                     
//--------------------------------------+
//| Create the "RadioGroup" element                                  |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateRadioGroup(void)
  {
//--- coordinates
   int x1=INDENT_LEFT;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y);
   int x2=x1+GROUP_WIDTH;
   int y2=y1+RADIO_HEIGHT;
//--- create
   if(!m_radio_group.Create(m_chart_id,m_name+"RadioGroup",m_subwin,x1,y1,x2,y2))  return(false);
   if(!Add(m_radio_group))                                                         return(false);
//--- fill out with strings
   //for(int i=0;i<2;i++)
     // if(!m_radio_group.AddItem("Item "+IntegerToString(i),1<<i))                  return(false);
      if(!m_radio_group.AddItem("Heliocentric ",1))                  return(false);
      if(!m_radio_group.AddItem("Geocentric ",2))                  return(false);
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
//| Create the "CheckGroup" element                                  |
//+------------------------------------------------------------------+
bool CControlsDialog::CreateCheckGroup(void)
  {
//--- coordinates
   int x1=INDENT_LEFT;
   int y1=INDENT_TOP+(EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (BUTTON_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (EDIT_HEIGHT+CONTROLS_GAP_Y)+
                     (RADIO_HEIGHT+CONTROLS_GAP_Y);
   int x2=x1+GROUP_WIDTH;
   int y2=y1+CHECK_HEIGHT;
//--- create
   if(!m_check_group.Create(m_chart_id,m_name+"CheckGroup",m_subwin,x1,y1,x2,y2))  return(false);
   if(!Add(m_check_group))                                                         return(false);
//--- fill out with strings
   //for(int i=0;i<10;i++)
     // if(!m_check_group.AddItem("Item "+IntegerToString(i),0))                  return(false);
      if(!m_check_group.AddItem("Mercury ",1<<0))                  return(false);
      if(!m_check_group.AddItem("Venus ",1<<1))                  return(false);
      if(!m_check_group.AddItem("Earth/Sun ",1<<2))                  return(false);
      if(!m_check_group.AddItem("Mars ",1<<3))                  return(false);
      if(!m_check_group.AddItem("Jupiter ",1<<4))                  return(false);
      if(!m_check_group.AddItem("Saturn ",1<<5))                  return(false);
      if(!m_check_group.AddItem("Uranus ",1<<6))                  return(false);
      if(!m_check_group.AddItem("Neptune ",1<<7))                  return(false);
      if(!m_check_group.AddItem("Pluto ",1<<8))                  return(false);
      if(!m_check_group.AddItem("Moon ",1<<9))                  return(false);
//--- succeed
   return(true);
  }
 
void CControlsDialog::OnClickButtonRedraw(void)
  {
   m_edit.Text("Last act.: Redraw");
  }
//+------------------------------------------------------------------+
//| Event handler                                                    |
//+------------------------------------------------------------------+
void CControlsDialog::OnClickButton2(void)
  {
   m_edit.Text("OnClickButton2");
  }
//+------------------------------------------------------------------+
//| Event handler                                                    |
//+------------------------------------------------------------------+
void CControlsDialog::OnClickButton3(void)
  {
   if(m_button3.Pressed())    m_edit.Text("OnClickButton3 "+"On");
   else                       m_edit.Text("OnClickButton3 "+"Off");
  }

//+------------------------------------------------------------------+
//| Event handler                                                    |
//+------------------------------------------------------------------+
void CControlsDialog::OnChangeSpinEdit()
  {
   m_edit.Text("Last act.: new aspect");
  }
//+------------------------------------------------------------------+
//| Event handler                                                    |
//+------------------------------------------------------------------+
void CControlsDialog::OnChangeListView(void)
  {
   m_edit.Text(" OnChangeListView "+" \""+m_list_view.Select()+"\"");
  }
//+------------------------------------------------------------------+
//| Event handler                                                    |
//+------------------------------------------------------------------+
void CControlsDialog::OnChangeComboBox(void)
  {
   m_edit.Text("OnChangeComboBox "+" \""+m_combo_box.Select()+"\"");
  }
//+------------------------------------------------------------------+
//| Event handler                                                    |
//+------------------------------------------------------------------+
void CControlsDialog::OnChangeRadioGroup(void)
  {
   m_edit.Text("Last act.: Sun/Earth selection ");
  }
//+------------------------------------------------------------------+
//| Event handler                                                    |
//+------------------------------------------------------------------+
void CControlsDialog::OnChangeCheckGroup(void)
  {
   m_edit.Text("Last act.: planet's selection");
   //if(m_check_group.Check(0))My_mercury=true;
  }
void CControlsDialog::OnEditPA(void)
  {
   m_edit.Text("Last act.: edit");
   //if(m_check_group.Check(0))My_mercury=true;
  }  
//+------------------------------------------------------------------+